==> openflowplugin-extension-nicira-0.5.3-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/nx/action/learn/grouping/nx/learn/FlowMods.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.nx.action.learn.grouping.nx.learn;
import org.opendaylight.yangtools.yang.binding.ChildOf;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.FlowModSpec;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.nx.action.learn.grouping.NxLearn;
import org.opendaylight.yangtools.yang.common.QName;
import org.opendaylight.yangtools.yang.binding.Augmentable;

/**
 * <p>This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-action</b>
 * <pre>
 * list flow-mods {
 *     choice flow-mod-spec {
 *         case flow-mod-add-match-from-field-case {
 *             container flow-mod-add-match-from-field {
 *                 leaf flow-mod-num-bits {
 *                     type uint16;
 *                 }
 *                 leaf src-field {
 *                     type uint32;
 *                 }
 *                 leaf src-ofs {
 *                     type uint16;
 *                 }
 *                 leaf dst-field {
 *                     type uint32;
 *                 }
 *                 leaf dst-ofs {
 *                     type uint16;
 *                 }
 *             }
 *         }
 *         case flow-mod-add-match-from-value-case {
 *             container flow-mod-add-match-from-value {
 *                 leaf flow-mod-num-bits {
 *                     type uint16;
 *                 }
 *                 leaf value {
 *                     type uint16;
 *                 }
 *                 leaf src-field {
 *                     type uint32;
 *                 }
 *                 leaf src-ofs {
 *                     type uint16;
 *                 }
 *             }
 *         }
 *         case flow-mod-copy-field-into-field-case {
 *             container flow-mod-copy-field-into-field {
 *                 leaf flow-mod-num-bits {
 *                     type uint16;
 *                 }
 *                 leaf src-field {
 *                     type uint32;
 *                 }
 *                 leaf src-ofs {
 *                     type uint16;
 *                 }
 *                 leaf dst-field {
 *                     type uint32;
 *                 }
 *                 leaf dst-ofs {
 *                     type uint16;
 *                 }
 *             }
 *         }
 *         case flow-mod-copy-value-into-field-case {
 *             container flow-mod-copy-value-into-field {
 *                 leaf flow-mod-num-bits {
 *                     type uint16;
 *                 }
 *                 leaf value {
 *                     type uint16;
 *                 }
 *                 leaf dst-field {
 *                     type uint32;
 *                 }
 *                 leaf dst-ofs {
 *                     type uint16;
 *                 }
 *             }
 *         }
 *         case flow-mod-output-to-port-case {
 *             container flow-mod-output-to-port {
 *                 leaf flow-mod-num-bits {
 *                     type uint16;
 *                 }
 *                 leaf src-field {
 *                     type uint32;
 *                 }
 *                 leaf src-ofs {
 *                     type uint16;
 *                 }
 *             }
 *         }
 *     }
 *     uses flow-mod-spec;
 * }
 * </pre>
 * The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-action/nx-action-learn-grouping/nx-learn/flow-mods</i>
 *
 * <p>To create instances of this class use {@link org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.nx.action.learn.grouping.nx.learn.FlowModsBuilder}.
 * @see org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.nx.action.learn.grouping.nx.learn.FlowModsBuilder
 *
 *
 */
public interface FlowMods
    extends
    ChildOf<NxLearn>,
    Augmentable<org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.nx.action.learn.grouping.nx.learn.FlowMods>,
    FlowModSpec
{



    public static final QName QNAME = org.opendaylight.yangtools.yang.common.QName.create("urn:opendaylight:openflowplugin:extension:nicira:action",
        "2014-07-14", "flow-mods").intern();


}

==> openflowplugin-extension-nicira-0.6.1-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/nx/action/learn/grouping/nx/learn/FlowMods.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.nx.action.learn.grouping.nx.learn;
import org.opendaylight.yangtools.yang.binding.ChildOf;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.FlowModSpec;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.nx.action.learn.grouping.NxLearn;
import org.opendaylight.yangtools.yang.common.QName;
import org.opendaylight.yangtools.yang.binding.Augmentable;

/**
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-action</b>
 * <pre>
 * list flow-mods {
 *     choice flow-mod-spec {
 *         case flow-mod-add-match-from-field-case {
 *             container flow-mod-add-match-from-field {
 *                 leaf flow-mod-num-bits {
 *                     type uint16;
 *                 }
 *                 leaf src-field {
 *                     type uint32;
 *                 }
 *                 leaf src-ofs {
 *                     type uint16;
 *                 }
 *                 leaf dst-field {
 *                     type uint32;
 *                 }
 *                 leaf dst-ofs {
 *                     type uint16;
 *                 }
 *             }
 *         }
 *         case flow-mod-add-match-from-value-case {
 *             container flow-mod-add-match-from-value {
 *                 leaf flow-mod-num-bits {
 *                     type uint16;
 *                 }
 *                 leaf value {
 *                     type uint16;
 *                 }
 *                 leaf src-field {
 *                     type uint32;
 *                 }
 *                 leaf src-ofs {
 *                     type uint16;
 *                 }
 *             }
 *         }
 *         case flow-mod-copy-field-into-field-case {
 *             container flow-mod-copy-field-into-field {
 *                 leaf flow-mod-num-bits {
 *                     type uint16;
 *                 }
 *                 leaf src-field {
 *                     type uint32;
 *                 }
 *                 leaf src-ofs {
 *                     type uint16;
 *                 }
 *                 leaf dst-field {
 *                     type uint32;
 *                 }
 *                 leaf dst-ofs {
 *                     type uint16;
 *                 }
 *             }
 *         }
 *         case flow-mod-copy-value-into-field-case {
 *             container flow-mod-copy-value-into-field {
 *                 leaf flow-mod-num-bits {
 *                     type uint16;
 *                 }
 *                 leaf value {
 *                     type uint16;
 *                 }
 *                 leaf dst-field {
 *                     type uint32;
 *                 }
 *                 leaf dst-ofs {
 *                     type uint16;
 *                 }
 *             }
 *         }
 *         case flow-mod-output-to-port-case {
 *             container flow-mod-output-to-port {
 *                 leaf flow-mod-num-bits {
 *                     type uint16;
 *                 }
 *                 leaf src-field {
 *                     type uint32;
 *                 }
 *                 leaf src-ofs {
 *                     type uint16;
 *                 }
 *             }
 *         }
 *     }
 *     uses flow-mod-spec;
 * }
 * </pre>The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-action/nx-action-learn-grouping/nx-learn/flow-mods</i>
 *
 * <p>To create instances of this class use {@link FlowModsBuilder}.
 * @see FlowModsBuilder
 *
 *
 */
public interface FlowMods
    extends
    ChildOf<NxLearn>,
    Augmentable<org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.nx.action.learn.grouping.nx.learn.FlowMods>,
    FlowModSpec
{



    public static final QName QNAME = org.opendaylight.yangtools.yang.common.QName.create("urn:opendaylight:openflowplugin:extension:nicira:action",
        "2014-07-14", "flow-mods").intern();


}
